import java.util.Set;
import java.util.HashMap;
import java.util.Iterator;

/*
 * Diese Klasse modelliert Rume in der Welt von Zuul.
 * 
 * Ein "Raum" reprsentiert einen Ort in der virtuellen Landschaft des
 * Spiels. Ein Raum ist mit anderen Rumen ber Ausgnge verbunden.
 * Fr jeden existierenden Ausgang hlt ein Raum eine Referenz auf 
 * den benachbarten Raum.
 * 
 * @author  Michael Kolling and David J. Barnes
 * @version 1.0 (Mrz 2003)
 */

class Raum 
{
    private String beschreibung,name;
    private HashMap ausgaenge;        // die Ausgnge dieses Raums

    /**
     * Erzeuge einen Raum mit einer Beschreibung. Ein Raum
     * hat anfangs keine Ausgnge.
     * @param beschreibung enthlt eine Beschreibung in der Form
     *        "in einer Kche" oder "auf einem Sportplatz".
     */
    public Raum(String beschreibung,String name) 
    {
        this.beschreibung = beschreibung;
        ausgaenge = new HashMap();
        this.name = name;
    }

    /**
     * Definiere einen Ausgang fr diesen Raum.
     * @param richtung die Richtung, in der der Ausgang liegen soll
     * @param nachbar der Raum, der ber diesen Ausgang erreicht wird
     */
    public void setzeAusgang(String richtung, Raum nachbar) 
    {
        ausgaenge.put(richtung, nachbar);
    }

    /**
     * Liefere die Beschreibung dieses Raums (die dem Konstruktor
     * bergeben wurde).
     */
    public String gibKurzbeschreibung()
    {
        return beschreibung;
    }
    
    public String gibName()
    {
        return name;
    }

    /**
     * Liefere eine lange Beschreibung dieses Raums, in der Form:
     *     Sie sind in der Kche.
     *     Ausgnge: nord west
     */
    public String gibLangeBeschreibung()
    {
        return  beschreibung + ".\n" + gibAusgaengeAlsString();
    }
    
    public void setzeLangeBeschreibung(String b)
    {
        beschreibung = b;
    }

    /**
     * Liefere eine Zeichenkette, die die Ausgnge dieses Raums
     * beschreibt, beispielsweise
     * "Ausgnge: north west".
     */
    private String gibAusgaengeAlsString()
    {
        String ergebnis = "Ausgnge:";
        Set keys = ausgaenge.keySet();
        for(Iterator iter = keys.iterator(); iter.hasNext(); )
            ergebnis += " " + iter.next();
        return ergebnis;
    }

    /**
     * Liefere den Raum, den wir erreichen, wenn wir aus diesem Raum
     * in die angegebene Richtung gehen. Liefere 'null', wenn in
     * dieser Richtung kein Ausgang ist.
     * @param richtung die Richtung, in die gegangen werden soll.
     */
    public Raum gibAusgang(String richtung) 
    {
        return (Raum)ausgaenge.get(richtung);
    }
}

